@@ -12,12 +12,12 @@
 ## class "DataControl"
 
 setMethod("getSize", "DataControl", function(x) slot(x, "size"))
-setMethod("setSize", "DataControl", 
-    function(x, size) eval.parent(substitute(slot(x, "size") <- size)))
 #setMethod("setSize", "DataControl", 
-#    function(x, size) {
-#        eval.parent(substitute(slot(x, "size") <- size, env=parent.frame()), n=2)
-#    })
+#    function(x, size) eval.parent(substitute(slot(x, "size") <- size)))
+setMethod("setSize", "DataControl", 
+    function(x, size) {
+        eval.parent(substitute(slot(x, "size") <- size, env=parent.frame()), n=2)
+    })
 
 setMethod("getDistribution", "DataControl", function(x) slot(x, "distribution"))
 setMethod("setDistribution", "DataControl", 
@@ -26,12 +26,12 @@ setMethod("setDistribution", "DataControl",
     })
 
 setMethod("getDots", "DataControl", function(x) slot(x, "dots"))
-setMethod("setDots", "DataControl", 
-    function(x, dots) eval.parent(substitute(slot(x, "dots") <- dots)))
 #setMethod("setDots", "DataControl", 
-#    function(x, dots) {
-#        eval.parent(substitute(slot(x, "dots") <- dots, env=parent.frame()), n=2)
-#    })
+#    function(x, dots) eval.parent(substitute(slot(x, "dots") <- dots)))
+setMethod("setDots", "DataControl", 
+    function(x, dots) {
+        eval.parent(substitute(slot(x, "dots") <- dots, env=parent.frame()), n=2)
+    })
 
 setMethod("getColnames", "DataControl", function(x) slot(x, "colnames"))
 setMethod("setColnames", "DataControl", 
@@ -61,140 +61,140 @@ setMethod("setCollect", "SampleControl",
     function(x, collect) eval.parent(substitute(slot(x, "collect") <- collect)))
 
 setMethod("getFun", "SampleControl", function(x) slot(x, "fun"))
-setMethod("setFun", "SampleControl", 
-    function(x, fun) eval.parent(substitute(slot(x, "fun") <- fun)))
 #setMethod("setFun", "SampleControl", 
-#    function(x, fun) {
-#        eval.parent(substitute(slot(x, "fun") <- fun, env=parent.frame()), n=2)
-#    })
+#    function(x, fun) eval.parent(substitute(slot(x, "fun") <- fun)))
+setMethod("setFun", "SampleControl", 
+    function(x, fun) {
+        eval.parent(substitute(slot(x, "fun") <- fun, env=parent.frame()), n=2)
+    })
 
 setMethod("getSize", "SampleControl", function(x) slot(x, "size"))
-setMethod("setSize", "SampleControl", 
-    function(x, size) eval.parent(substitute(slot(x, "size") <- size)))
 #setMethod("setSize", "SampleControl", 
-#    function(x, size) {
-#        eval.parent(substitute(slot(x, "size") <- size, env=parent.frame()), n=2)
-#    })
+#    function(x, size) eval.parent(substitute(slot(x, "size") <- size)))
+setMethod("setSize", "SampleControl", 
+    function(x, size) {
+        eval.parent(substitute(slot(x, "size") <- size, env=parent.frame()), n=2)
+    })
 
 setMethod("getProb", "SampleControl", function(x) slot(x, "prob"))
-setMethod("setProb", "SampleControl", 
-    function(x, prob) eval.parent(substitute(slot(x, "prob") <- prob)))
 #setMethod("setProb", "SampleControl", 
-#    function(x, prob) {
-#        eval.parent(substitute(slot(x, "prob") <- prob, env=parent.frame()), n=2)
-#    })
+#    function(x, prob) eval.parent(substitute(slot(x, "prob") <- prob)))
+setMethod("setProb", "SampleControl", 
+    function(x, prob) {
+        eval.parent(substitute(slot(x, "prob") <- prob, env=parent.frame()), n=2)
+    })
 
 setMethod("getDots", "SampleControl", function(x) slot(x, "dots"))
-setMethod("setDots", "SampleControl", 
-    function(x, dots) eval.parent(substitute(slot(x, "dots") <- dots)))
 #setMethod("setDots", "SampleControl", 
-#    function(x, dots) {
-#        eval.parent(substitute(slot(x, "dots") <- dots, env=parent.frame()), n=2)
-#    })
+#    function(x, dots) eval.parent(substitute(slot(x, "dots") <- dots)))
+setMethod("setDots", "SampleControl", 
+    function(x, dots) {
+        eval.parent(substitute(slot(x, "dots") <- dots, env=parent.frame()), n=2)
+    })
 
 
-### class "TwoStageControl"
-#
-#setMethod("getDesign", "TwoStageControl", function(x) slot(x, "design"))
-#setMethod("setDesign", "TwoStageControl", 
-#    function(x, design) eval.parent(substitute(slot(x, "design") <- design)))
-#
-#setMethod("getGrouping", "TwoStageControl", function(x) slot(x, "grouping"))
-#setMethod("setGrouping", "TwoStageControl", 
-#    function(x, grouping) {
-#        eval.parent(substitute(slot(x, "grouping") <- grouping))
-#    })
-#
-#
-## utility function to check the 'stage' argument of the following methods
-#checkStage <- function(stage) {
-#    if(!isTRUE(stage == 1) && !isTRUE(stage == 2)) {
-#        stop("'stage' must be either 1 or 2")
-#    }
-#}
-#
-## in the following mutators: 'stage' is not available in the environment of 
-## the generic function and needs to be extracted from the additional arguments
-#
-#setMethod("getFun", "TwoStageControl", 
-#    function(x, stage = NULL) {
-#        fun <- slot(x, "fun")
-#        if(is.null(stage)) fun
-#        else {
-#            checkStage(stage)
-#            fun[[stage]]
-#        }
-#    })
-#setMethod("setFun", "TwoStageControl", 
-#    function(x, fun, stage = NULL) {
-#        pf <- parent.frame()  # environment of generic function
-#        if(is.null(stage)) expr <- substitute(slot(x, "fun") <- fun, pf)
-#        else {
-#            checkStage(stage)
-#            expr <- substitute(slot(x, "fun")[[list(...)$stage]] <- fun, pf)
-#        }
-#        eval.parent(expr, n=2)  # evaluate expression
-#    })
-#
-#setMethod("getSize", "TwoStageControl", 
-#    function(x, stage = NULL) {
-#        size <- slot(x, "size")
-#        if(is.null(stage)) size
-#        else {
-#            checkStage(stage)
-#            size[[stage]]
-#        }
-#    })
-#setMethod("setSize", "TwoStageControl", 
-#    function(x, size, stage = NULL) {
-#        pf <- parent.frame()  # environment of generic function
-#        if(is.null(stage)) expr <- substitute(slot(x, "size") <- size, pf)
-#        else {
-#            checkStage(stage)
-#            expr <- substitute(slot(x, "size")[[list(...)$stage]] <- size, pf)
-#        }
-#        eval.parent(expr, n=2)  # evaluate expression
-#    })
-#
-#setMethod("getProb", "TwoStageControl", 
-#    function(x, stage = NULL) {
-#        prob <- slot(x, "prob")
-#        if(is.null(stage)) prob
-#        else {
-#            checkStage(stage)
-#            prob[[stage]]
-#        }
-#    })
-#setMethod("setProb", "TwoStageControl", 
-#    function(x, prob, stage = NULL) {
-#        pf <- parent.frame()  # environment of generic function
-#        if(is.null(stage)) expr <- substitute(slot(x, "prob") <- prob, pf)
-#        else {
-#            checkStage(stage)
-#            expr <- substitute(slot(x, "prob")[[list(...)$stage]] <- prob, pf)
-#        }
-#        eval.parent(expr, n=2)  # evaluate expression
-#    })
-#
-#setMethod("getDots", "TwoStageControl", 
-#    function(x, stage = NULL) {
-#        dots <- slot(x, "dots")
-#        if(is.null(stage)) dots
-#        else {
-#            checkStage(stage)
-#            dots[[stage]]
-#        }
-#    })
-#setMethod("setDots", "TwoStageControl", 
-#    function(x, dots, stage = NULL) {
-#        pf <- parent.frame()  # environment of generic function
-#        if(is.null(stage)) expr <- substitute(slot(x, "dots") <- dots, pf)
-#        else {
-#            checkStage(stage)
-#            expr <- substitute(slot(x, "dots")[[list(...)$stage]] <- dots, pf)
-#        }
-#        eval.parent(expr, n=2)  # evaluate expression
-#    })
+## class "TwoStageControl"
+
+setMethod("getDesign", "TwoStageControl", function(x) slot(x, "design"))
+setMethod("setDesign", "TwoStageControl", 
+    function(x, design) eval.parent(substitute(slot(x, "design") <- design)))
+
+setMethod("getGrouping", "TwoStageControl", function(x) slot(x, "grouping"))
+setMethod("setGrouping", "TwoStageControl", 
+    function(x, grouping) {
+        eval.parent(substitute(slot(x, "grouping") <- grouping))
+    })
+
+
+# utility function to check the 'stage' argument of the following methods
+checkStage <- function(stage) {
+    if(!isTRUE(stage == 1) && !isTRUE(stage == 2)) {
+        stop("'stage' must be either 1 or 2")
+    }
+}
+
+# in the following mutators: 'stage' is not available in the environment of 
+# the generic function and needs to be extracted from the additional arguments
+
+setMethod("getFun", "TwoStageControl", 
+    function(x, stage = NULL) {
+        fun <- slot(x, "fun")
+        if(is.null(stage)) fun
+        else {
+            checkStage(stage)
+            fun[[stage]]
+        }
+    })
+setMethod("setFun", "TwoStageControl", 
+    function(x, fun, stage = NULL) {
+        pf <- parent.frame()  # environment of generic function
+        if(is.null(stage)) expr <- substitute(slot(x, "fun") <- fun, pf)
+        else {
+            checkStage(stage)
+            expr <- substitute(slot(x, "fun")[[list(...)$stage]] <- fun, pf)
+        }
+        eval.parent(expr, n=2)  # evaluate expression
+    })
+
+setMethod("getSize", "TwoStageControl", 
+    function(x, stage = NULL) {
+        size <- slot(x, "size")
+        if(is.null(stage)) size
+        else {
+            checkStage(stage)
+            size[[stage]]
+        }
+    })
+setMethod("setSize", "TwoStageControl", 
+    function(x, size, stage = NULL) {
+        pf <- parent.frame()  # environment of generic function
+        if(is.null(stage)) expr <- substitute(slot(x, "size") <- size, pf)
+        else {
+            checkStage(stage)
+            expr <- substitute(slot(x, "size")[[list(...)$stage]] <- size, pf)
+        }
+        eval.parent(expr, n=2)  # evaluate expression
+    })
+
+setMethod("getProb", "TwoStageControl", 
+    function(x, stage = NULL) {
+        prob <- slot(x, "prob")
+        if(is.null(stage)) prob
+        else {
+            checkStage(stage)
+            prob[[stage]]
+        }
+    })
+setMethod("setProb", "TwoStageControl", 
+    function(x, prob, stage = NULL) {
+        pf <- parent.frame()  # environment of generic function
+        if(is.null(stage)) expr <- substitute(slot(x, "prob") <- prob, pf)
+        else {
+            checkStage(stage)
+            expr <- substitute(slot(x, "prob")[[list(...)$stage]] <- prob, pf)
+        }
+        eval.parent(expr, n=2)  # evaluate expression
+    })
+
+setMethod("getDots", "TwoStageControl", 
+    function(x, stage = NULL) {
+        dots <- slot(x, "dots")
+        if(is.null(stage)) dots
+        else {
+            checkStage(stage)
+            dots[[stage]]
+        }
+    })
+setMethod("setDots", "TwoStageControl", 
+    function(x, dots, stage = NULL) {
+        pf <- parent.frame()  # environment of generic function
+        if(is.null(stage)) expr <- substitute(slot(x, "dots") <- dots, pf)
+        else {
+            checkStage(stage)
+            expr <- substitute(slot(x, "dots")[[list(...)$stage]] <- dots, pf)
+        }
+        eval.parent(expr, n=2)  # evaluate expression
+    })
 
 
 ## class "SampleSetup"
@@ -250,28 +250,28 @@ setMethod("setDistribution", "DCARContControl",
     })
 
 setMethod("getDots", "DCARContControl", function(x) slot(x, "dots"))
-setMethod("setDots", "DCARContControl", 
-    function(x, dots) eval.parent(substitute(slot(x, "dots") <- dots)))
 #setMethod("setDots", "DCARContControl", 
-#    function(x, dots) {
-#        eval.parent(substitute(slot(x, "dots") <- dots, env=parent.frame()), n=2)
-#    })
+#    function(x, dots) eval.parent(substitute(slot(x, "dots") <- dots)))
+setMethod("setDots", "DCARContControl", 
+    function(x, dots) {
+        eval.parent(substitute(slot(x, "dots") <- dots, env=parent.frame()), n=2)
+    })
 
 setMethod("getFun", "DARContControl", function(x) slot(x, "fun"))
-setMethod("setFun", "DARContControl", 
-    function(x, fun) eval.parent(substitute(slot(x, "fun") <- fun)))
 #setMethod("setFun", "DARContControl", 
-#    function(x, fun) {
-#        eval.parent(substitute(slot(x, "fun") <- fun, env=parent.frame()), n=2)
-#    })
+#    function(x, fun) eval.parent(substitute(slot(x, "fun") <- fun)))
+setMethod("setFun", "DARContControl", 
+    function(x, fun) {
+        eval.parent(substitute(slot(x, "fun") <- fun, env=parent.frame()), n=2)
+    })
 
 setMethod("getDots", "DARContControl", function(x) slot(x, "dots"))
-setMethod("setDots", "DARContControl", 
-    function(x, dots) eval.parent(substitute(slot(x, "dots") <- dots)))
 #setMethod("setDots", "DARContControl", 
-#    function(x, dots) {
-#        eval.parent(substitute(slot(x, "dots") <- dots, env=parent.frame()), n=2)
-#    })
+#    function(x, dots) eval.parent(substitute(slot(x, "dots") <- dots)))
+setMethod("setDots", "DARContControl", 
+    function(x, dots) {
+        eval.parent(substitute(slot(x, "dots") <- dots, env=parent.frame()), n=2)
+    })
 
 
 ## class "NAControl"
@@ -337,20 +337,20 @@ setMethod("setDesign", "SimControl",
     function(x, design) eval.parent(substitute(slot(x, "design") <- design)))
 
 setMethod("getFun", "SimControl", function(x) slot(x, "fun"))
-setMethod("setFun", "SimControl", 
-    function(x, fun) eval.parent(substitute(slot(x, "fun") <- fun)))
 #setMethod("setFun", "SimControl", 
-#    function(x, fun) {
-#        eval.parent(substitute(slot(x, "fun") <- fun, env=parent.frame()), n=2)
-#    })
+#    function(x, fun) eval.parent(substitute(slot(x, "fun") <- fun)))
+setMethod("setFun", "SimControl", 
+    function(x, fun) {
+        eval.parent(substitute(slot(x, "fun") <- fun, env=parent.frame()), n=2)
+    })
 
 setMethod("getDots", "SimControl", function(x) slot(x, "dots"))
-setMethod("setDots", "SimControl", 
-    function(x, dots) eval.parent(substitute(slot(x, "dots") <- dots)))
 #setMethod("setDots", "SimControl", 
-#    function(x, dots) {
-#        eval.parent(substitute(slot(x, "dots") <- dots, env=parent.frame()), n=2)
-#    })
+#    function(x, dots) eval.parent(substitute(slot(x, "dots") <- dots)))
+setMethod("setDots", "SimControl", 
+    function(x, dots) {
+        eval.parent(substitute(slot(x, "dots") <- dots, env=parent.frame()), n=2)
+    })
 
 setMethod("getSAE", "SimControl", function(x) slot(x, "SAE"))
 setMethod("setSAE", "SimControl", 
