@@ -8,8 +8,8 @@ setMethod("clusterRunSimulation",
     signature(cl = "ANY", x = "ANY", setup = "ANY", 
         nrep = "ANY", control = "missing"),
     function(cl, x, setup, nrep, control, contControl = NULL, 
-            NAControl = NULL, design = character(), fun, ..., 
-            SAE = FALSE) {
+        NAControl = NULL, design = character(), fun, ..., 
+        SAE = FALSE) {
         control <- SimControl(contControl=contControl, NAControl=NAControl, 
             design=design, fun=fun, dots=list(...), SAE=SAE)
         clusterAssign(cl, "control", control)
@@ -28,9 +28,9 @@ setMethod("clusterRunSimulation",
     signature(cl = "ANY", x = "data.frame", setup = "VirtualSampleControl", 
         nrep = "missing", control = "SimControl"),
     function(cl, x, setup, nrep, control, contControl = NULL, 
-            NAControl = NULL, design = character(), fun, ..., 
-            SAE = FALSE) {
-            setup <- clusterSetup(cl, x, setup)
+        NAControl = NULL, design = character(), fun, ..., 
+        SAE = FALSE) {
+        setup <- clusterSetup(cl, x, setup)
         clusterAssign(cl, "setup", setup)
         clusterRunSimulation(cl, x, setup, control=control)
     })
@@ -39,9 +39,9 @@ setMethod("clusterRunSimulation",
     signature(cl = "ANY", x = "data.frame", setup = "SampleSetup", 
         nrep = "missing", control = "SimControl"),
     function(cl, x, setup, nrep, control, contControl = NULL, 
-            NAControl = NULL, design = character(), fun, ..., 
-            SAE = FALSE) {
-            # initializations
+        NAControl = NULL, design = character(), fun, ..., 
+        SAE = FALSE) {
+        # initializations
         nsam <- length(setup)
         design <- getDesign(control)
         if(nsam == 0) {  # nothing to do
@@ -66,9 +66,9 @@ setMethod("clusterRunSimulation",
     signature(cl = "ANY", x = "VirtualDataControl", 
         setup = "missing", nrep = "numeric", control = "SimControl"),
     function(cl, x, setup, nrep, control, contControl = NULL, 
-            NAControl = NULL, design = character(), fun, ..., 
-            SAE = FALSE) {
-            # initializations
+        NAControl = NULL, design = character(), fun, ..., 
+        SAE = FALSE) {
+        # initializations
         if(length(nrep) == 0) stop("'nrep' must be a non-negative integer")
         else if(length(nrep) > 1) nrep <- nrep[1]
         design <- getDesign(control)
@@ -89,7 +89,34 @@ setMethod("clusterRunSimulation",
     })
 
 
-## TODO: mixed simulation designs
+## mixed simulation designs
+setMethod("clusterRunSimulation", 
+    signature(cl = "ANY", x = "VirtualDataControl", 
+        setup = "VirtualSampleControl", nrep = "numeric", 
+        control = "SimControl"),
+    function(cl, x, setup, nrep, control, contControl = NULL, 
+        NAControl = NULL, design = character(), fun, ..., 
+        SAE = FALSE) {
+        # initializations
+        if(length(nrep) == 0) stop("'nrep' must be a non-negative integer")
+        else if(length(nrep) > 1) nrep <- nrep[1]
+        nsam <- length(setup)
+        design <- getDesign(control)
+        if(nrep == 0 || nsam == 0) {  # nothing to do
+            return(SimResults(design=design, dataControl=x, 
+                    sampleControl=setup, nrep=nrep, control=control))
+        }
+        contControl <- getContControl(control)
+        epsilon <- if(is.null(contControl)) numeric() else getEpsilon(contControl)
+        NAControl <- getNAControl(control)
+        NArate <- if(is.null(NAControl)) numeric() else getNArate(NAControl)
+        # run the simulations (generate data repeatedly and draw samples)
+        r <- 1:nrep
+        tmp <- parLapply(cl, r, mixedSimulation, x, setup, control)
+        # construct results
+        getSimResults(tmp, 1:nsam, r, epsilon=epsilon, NArate=NArate, 
+            design=design, dataControl=x, sampleControl=setup, control=control)
+    })
 
 
 ## simulation with replications based on (possibly) real data
@@ -97,9 +124,9 @@ setMethod("clusterRunSimulation",
     signature(cl = "ANY", x = "data.frame", setup = "missing", 
         nrep = "numeric", control = "SimControl"),
     function(cl, x, setup, nrep, control, contControl = NULL, 
-            NAControl = NULL, design = character(), fun, ..., 
-            SAE = FALSE) {
-            # initializations
+        NAControl = NULL, design = character(), fun, ..., 
+        SAE = FALSE) {
+        # initializations
         if(length(nrep) == 0) stop("'nrep' must be a non-negative integer")
         else if(length(nrep) > 1) nrep <- nrep[1]
         design <- getDesign(control)
